@@ -2,10 +2,10 @@
 
 Context : SRP
 Module  : SRPConstants.py
-Version : 1.14.2
+Version : 1.15.3
 Status  : approved
 Author  : Stefano Covino, Daniele Malesani
-Date    : 13/12/2012
+Date    : 01/10/2020
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.merate.mi.astro.it/~covino
 Purpose : Collection of constants, functions and classes for SRP.
@@ -85,7 +85,11 @@ History : (20/05/2003) First version.
         : (28/02/2012) TNG Dolores spec and pol entries.
         : (31/07/2012) Updated TNG pol entries.
         : (27/08/2012) Updated constants for average sigma-clipping.
-        : (13/12/2012) Imporvements to FORS imaging polarimetry keywords.
+        : (13/12/2012) Improvements to FORS imaging polarimetry keywords.
+        : (29/07/2015) python3 porting.
+        : (22/08/2017) Better keywords for imaging polarimetry.
+        : (17/01/2019) More keywords for imaging polarimetry.
+        : (01/10/2020) New keyword for chip type.
 """
 
 import os
@@ -204,6 +208,7 @@ HIERARCH ESO DET READ CLOCK
 HIERARCH ESO TEL AIRM START
 HIERARCH ESO TEL AIRM END
 HIERARCH ESO INS PIXSCALE
+HIERARCH ESO DET CHIP1 NAME
 EXTNAME
 """
 SRPLASCIMA  = "SRPLASCIMA"
@@ -476,20 +481,21 @@ DATE-OBS
 EXPTIME
 RA
 DEC
-OBJECT
 INSTRUME
-AIRMASS
-IMAGETYP
-FILTER1
-PARANGST
-RETANG
+HIERARCH ESO TEL AIRM START
+HIERARCH ESO DPR TYPE
+HIERARCH ESO INS FILT1 NAME
+HIERARCH ESO TEL PARANGS START
+HIERARCH ESO ADA POSANG
 HIERARCH ESO DPR CATG
 HIERARCH ESO DPR TECH
 HIERARCH ESO INS PIXSCALE
 HIERARCH ESO INS MODE
 HIERARCH ESO INS COLL NAME
 HIERARCH ESO INS RETA2 POSANG
+HIERARCH ESO INS RETA4 POSANG
 HIERARCH ESO OBS TARG NAME
+HIERARCH ESO DET CHIP1 NAME
 EXTNAME
 """
 SRPVLTXSHOOTER = "VLTXSHOOTER"
@@ -582,9 +588,9 @@ SRPPREKEYDICT = {SRPVLTFORSIMA:VLTFORSIMA, SRPLASCIMA:LASCIMA, SRPTNGDOLORESIMA:
 # Site coordinates
 # ESO La Silla
 class SiteCoord:
- def __init__ (self, lat, long):
-  self.Lat = str(lat)
-  self.Long = str(long)
+ def __init__ (self, latc, longc):
+  self.Lat = str(latc)
+  self.Long = str(longc)
 SiteDict = {'LaSilla' : SiteCoord(-29.2567,-70.7292), 'Paranal' : SiteCoord('-24:51:00', '-70:27:00'),
  'Merate' : SiteCoord('45:41:54','9:25:45'), 'TNG' : SiteCoord('28:46:00','-17:53:00'),
  'CalarAlto' : SiteCoord('37:13:25', '2:32:46'), 'NOT' : SiteCoord('28:45:26','-17:53:00'),
