@@ -17,7 +17,7 @@ History : (25/06/2010) First version.
 """
 
 import numpy
-from CartesianVectorClass import CartesianVector
+from .CartesianVectorClass import CartesianVector
 
 
 def FastAngularDistance (a1,l1,a2,l2):
