@@ -16,7 +16,7 @@ History : (19/03/2011) First version.
 
 import math
 import scipy.integrate
-from VoigtIntegrand import VoigtIntegrand
+from .VoigtIntegrand import VoigtIntegrand
 
 
 def VoigtFunct (a,v):
